@@ -33,7 +33,9 @@ DVB_APPS_DIRS = ("/usr/share/dvb",
                  "/usr/share/doc/dvb-utils/examples/scan")
                  
 COUNTRIES = {
+    "ad": "Andorra",
     "at": "Austria",
+    "az": "Azerbaijan",
     "au": "Australia",
     "be": "Belgium",
     "ch": "Switzerland",
@@ -45,20 +47,82 @@ COUNTRIES = {
     "fr": "France",
     "gr": "Greece",
     "hk": "Hong Kong",
-    "hr": "Hungary",
+    "hr": "Croatia",
+    "hu": "Hungary",
+    "il": "Israel",
+    "ir": "Iran, Islamic Republic of",
     "is": "Iceland",
     "it": "Italy",
+    "lt": "Lithuania",
     "lu": "Luxemburg",
+    "lv": "Latvia",
     "nl": "Netherlands",
     "no": "Norway",
     "nz": "New Zealand",
     "pl": "Poland",
+    "ro": "Romania",
     "se": "Sweden",
+    "si": "Slovenia",
     "sk": "Slovakia",
     "tw": "Taiwan",
     "uk": "United Kingdom",
+    "vn": "Viet Nam",
 }
 
+COUNTRIES_DVB_T = (
+    "ad",
+    "at",
+    "az",
+    "au",
+    "be",
+    "ch",
+    "cz",
+    "de",
+    "dk",
+    "es",
+    "fi",
+    "fr",
+    "gr",
+    "hk",
+    "hr",
+    "hu",
+    "il",
+    "ir",
+    "is",
+    "it",
+    "lt",
+    "lu",
+    "lv",
+    "nl",
+    "no",
+    "nz",
+    "pl",
+    "ro",
+    "se",
+    "si",
+    "sk",
+    "tw",
+    "uk",
+    "vn",
+)
+
+COUNTRIES_DVB_C = (
+    "at",
+    "be",
+    "ch",
+    "cz",
+    "de",
+    "dk",
+    "es",
+    "fi",
+    "fr",
+    "hu",
+    "lu",
+    "nl",
+    "no",
+    "se",
+)
+
 class InitialTuningDataPage(BasePage):
     
     __gsignals__ = {
@@ -107,9 +171,9 @@ class InitialTuningDataPage(BasePage):
         return self.__tuning_data
         
     def _create_table(self):
-        self.table = Gtk.Table(rows=4, columns=2)
-        self.table.set_row_spacings(6)
-        self.table.set_col_spacings(18)
+        self.table = Gtk.Grid(orientation=Gtk.Orientation.VERTICAL)
+        self.table.set_row_spacing(6)
+        self.table.set_column_spacing(18)
         self.table.show()
         self.pack_start(self.table, True, True, 0)
 
@@ -140,19 +204,16 @@ class InitialTuningDataPage(BasePage):
         self.providers_view = None
         
         countries = {self.NOT_LISTED: _("Not listed")}
-        country_codes = ("at", "au", "be", "ch", "cz", "de", "dk", "es", "fi", "fr",
-            "gr", "hr", "hk", "is", "it", "lu", "nl", "nz", "pl", "se", "sk",
-            "tw", "uk",)
         t = gettext.translation("iso_3166", fallback=True)
-        for lang in country_codes:
+        for lang in COUNTRIES_DVB_T:
             countries[lang] = t.ugettext(COUNTRIES[lang])
         
         self._create_table()
 
-        country = Gtk.Label()
+        country = Gtk.Label(halign=Gtk.Align.START)
         country.set_markup_with_mnemonic(_("_Country:"))
         country.show()
-        self.table.attach(country, 0, 1, 0, 1, yoptions=0, xoptions=Gtk.AttachOptions.FILL)
+        self.table.add(country)
 
         # name, code    
         self.countries = Gtk.ListStore(str, str)
@@ -163,20 +224,22 @@ class InitialTuningDataPage(BasePage):
             self.countries.append([name, code])
     
         self.country_combo = Gtk.ComboBox.new_with_model_and_entry(self.countries)
+        self.country_combo.set_hexpand(True)
         self.country_combo.connect('changed', self.on_country_changed)
         self.__data_dir = "dvb-t"
         cell = Gtk.CellRendererText()
         self.country_combo.pack_start(cell, True)
         self.country_combo.set_entry_text_column(0)
         self.country_combo.show()
-        self.table.attach(self.country_combo, 1, 2, 0, 1, yoptions=0)
+        self.table.attach_next_to(self.country_combo, country,
+            Gtk.PositionType.RIGHT, 1, 1)
         self.country_combo.set_active(0)
         country.set_mnemonic_widget(self.country_combo)
         
         providers = Gtk.Label()
         providers.set_markup_with_mnemonic(_("_Antenna:"))
         providers.show()
-        self.table.attach(providers, 0, 1, 1, 2, yoptions=0, xoptions=Gtk.AttachOptions.FILL)
+        self.table.add(providers)
         
         self.providers = Gtk.ListStore(str, str)
         self.providers.set_sort_column_id(0, Gtk.SortType.ASCENDING)
@@ -188,7 +251,9 @@ class InitialTuningDataPage(BasePage):
             self.on_providers_changed)
         providers.set_mnemonic_widget(self.providers_view)
         
-        self.table.attach(scrolledview, 0, 2, 2, 3)
+        scrolledview.set_property("expand", True)
+        self.table.attach_next_to(scrolledview, providers,
+            Gtk.PositionType.BOTTOM, 2, 1)
         
         self.providers_view.set_sensitive(False)
    
@@ -213,18 +278,17 @@ class InitialTuningDataPage(BasePage):
         
     def setup_dvb_c(self):
         countries = {}
-        country_codes = ("at", "be", "ch", "de", "fi", "lu", "nl", "se", "no",)
         t = gettext.translation("iso_3166", fallback=True)
-        for lang in country_codes:
+        for lang in COUNTRIES_DVB_C:
             countries[lang] = t.ugettext(COUNTRIES[lang])
-            
+
         self._create_table()
-            
-        country = Gtk.Label()
+
+        country = Gtk.Label(halign=Gtk.Align.START)
         country.set_markup_with_mnemonic(_("_Country:"))
         country.show()
-        self.table.attach(country, 0, 1, 0, 1, yoptions=0, xoptions=Gtk.AttachOptions.FILL)
-    
+        self.table.add(country)
+
         self.countries = Gtk.ListStore(str, str)
         self.countries.set_sort_column_id(0, Gtk.SortType.ASCENDING)
         self.countries.set_sort_func(0, self.combobox_sort_func, None)
@@ -233,19 +297,21 @@ class InitialTuningDataPage(BasePage):
             self.countries.append([name, code])
     
         self.country_combo = Gtk.ComboBox.new_with_model_and_entry(self.countries)
+        self.country_combo.set_hexpand(True)
         self.country_combo.connect('changed', self.on_country_changed)
         self.__data_dir = "dvb-c"
         cell = Gtk.CellRendererText()
         self.country_combo.pack_start(cell, True)
         self.country_combo.set_entry_text_column(0)
         self.country_combo.show()
-        self.table.attach(self.country_combo, 1, 2, 0, 1, yoptions=0)
+        self.table.attach_next_to(self.country_combo, country,
+            Gtk.PositionType.RIGHT, 1, 1)
         country.set_mnemonic_widget(self.country_combo)
         
         providers = Gtk.Label()
         providers.set_markup_with_mnemonic(_("_Providers:"))
         providers.show()
-        self.table.attach(providers, 0, 1, 1, 2, yoptions=0, xoptions=Gtk.AttachOptions.FILL)
+        self.table.add(providers)
         
         self.providers = Gtk.ListStore(str, str)
         self.providers.set_sort_column_id(0, Gtk.SortType.ASCENDING)
@@ -256,7 +322,9 @@ class InitialTuningDataPage(BasePage):
             self.on_providers_changed)
         providers.set_mnemonic_widget(self.providers_view)
         
-        self.table.attach(scrolledview, 0, 2, 2, 3)
+        scrolledview.set_property("expand", True)
+        self.table.attach_next_to(scrolledview, providers,
+            Gtk.PositionType.BOTTOM, 2, 1)
         self.providers_view.set_sensitive(False)
          
     def _create_providers_treeview(self, providers, col_name):
